@@ -1759,10 +1759,11 @@ exports.setUpEditor = function(serviceRegistry, pluginRegistry, preferences, rea
 					setup.editorViewers.push(setup.createEditorViewer());
 					setup.setActiveEditorViewer(setup.editorViewers[0]);
 					if (enableSplitEditor) {
-						var mode = Number(sessionStorage.splitterSelection) || MODE_SINGLE;
 						setup.createSplitMenu();
-						setup.splitterMode = MODE_SINGLE;
-						setup.splitMenuChoices[mode].callback();
+//						var mode = Number(sessionStorage.splitterSelection) || MODE_SINGLE;
+//						setup.splitterMode = MODE_SINGLE;
+//						setup.splitMenuChoices[mode].callback();
+						setup.setSplitterMode(MODE_SINGLE);
 					}
 					setup.load();
 				});
